core.models.gemnet_oc.layers.base_layers
========================================

.. py:module:: core.models.gemnet_oc.layers.base_layers

.. autoapi-nested-parse::

   Copyright (c) Meta, Inc. and its affiliates.
   This source code is licensed under the MIT license found in the
   LICENSE file in the root directory of this source tree.



Classes
-------

.. autoapisummary::

   core.models.gemnet_oc.layers.base_layers.Dense
   core.models.gemnet_oc.layers.base_layers.ScaledSiLU
   core.models.gemnet_oc.layers.base_layers.ResidualLayer


Module Contents
---------------

.. py:class:: Dense(in_features: int, out_features: int, bias: bool = False, activation: str | None = None)

   Bases: :py:obj:`torch.nn.Module`


   Combines dense layer with scaling for silu activation.

   :param in_features: Input embedding size.
   :type in_features: int
   :param out_features: Output embedding size.
   :type out_features: int
   :param bias: True if use bias.
   :type bias: bool
   :param activation: Name of the activation function to use.
   :type activation: str


   .. py:attribute:: linear


   .. py:method:: reset_parameters(initializer=he_orthogonal_init) -> None


   .. py:method:: forward(x)


.. py:class:: ScaledSiLU

   Bases: :py:obj:`torch.nn.Module`


   Base class for all neural network modules.

   Your models should also subclass this class.

   Modules can also contain other Modules, allowing to nest them in
   a tree structure. You can assign the submodules as regular attributes::

       import torch.nn as nn
       import torch.nn.functional as F

       class Model(nn.Module):
           def __init__(self):
               super().__init__()
               self.conv1 = nn.Conv2d(1, 20, 5)
               self.conv2 = nn.Conv2d(20, 20, 5)

           def forward(self, x):
               x = F.relu(self.conv1(x))
               return F.relu(self.conv2(x))

   Submodules assigned in this way will be registered, and will have their
   parameters converted too when you call :meth:`to`, etc.

   .. note::
       As per the example above, an ``__init__()`` call to the parent class
       must be made before assignment on the child.

   :ivar training: Boolean represents whether this module is in training or
                   evaluation mode.
   :vartype training: bool


   .. py:attribute:: scale_factor


   .. py:attribute:: _activation


   .. py:method:: forward(x)


.. py:class:: ResidualLayer(units: int, nLayers: int = 2, layer=Dense, **layer_kwargs)

   Bases: :py:obj:`torch.nn.Module`


   Residual block with output scaled by 1/sqrt(2).

   :param units: Input and output embedding size.
   :type units: int
   :param nLayers: Number of dense layers.
   :type nLayers: int
   :param layer: Class for the layers inside the residual block.
   :type layer: torch.nn.Module
   :param layer_kwargs: Keyword arguments for initializing the layers.
   :type layer_kwargs: str


   .. py:attribute:: dense_mlp


   .. py:attribute:: inv_sqrt_2


   .. py:method:: forward(input)


